RATableAccordionStyle class

Constructors

RATableAccordionStyle({Color? headColor, Color? iconColor, List<Color>? levelColors, Color? lineColor})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headColor Color?
final
iconColor Color?
final
levelColors List<Color>?
final
lineColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited