RATableRowData class

Constructors

RATableRowData({required List<RATableCell> cells, bool isSelected = false, bool isExpanded = false, bool isIndeterminate = false, Widget? child, List<RATableRowData>? children})

Properties

cells List<RATableCell>
final
child Widget?
final
children List<RATableRowData>?
final
hasChildrenRows bool
no setter
hasChildWidget bool
no setter
hasExpandableContent bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isExpanded bool
getter/setter pair
isIndeterminate bool
getter/setter pair
isSelected bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited